:mod:`joblib`.register_compressor
==============================================

.. currentmodule:: joblib

.. autofunction:: register_compressor

.. include:: joblib.register_compressor.examples

.. raw:: html

    <div class="clearer"></div>